@@ -34,7 +34,7 @@
 /*
  * Certificate handling code
  *
- * $Id: certdb.c,v 1.46.2.3 2003/07/09 22:39:45 wtc%netscape.com Exp $
+ * $Id: certdb.c,v 1.51 2003/03/24 19:08:58 relyea%netscape.com Exp $
  */
 
 #include "nssilock.h"
@@ -45,7 +45,6 @@
 #include "secder.h"
 #include "secoid.h"
 #include "secasn1.h"
-#include "blapi.h"		/* for SHA1_HashBuf */
 #include "genname.h"
 #include "keyhi.h"
 #include "secitem.h"
@@ -1201,6 +1200,8 @@ CERT_CheckKeyUsage(CERTCertificate *cert, unsigned int requiredUsage)
      */
     if ( requiredUsage & KU_KEY_AGREEMENT_OR_ENCIPHERMENT ) {
 	key = CERT_ExtractPublicKey(cert);
+	if (!key)
+	    return SECFailure;
 	if ( ( key->keyType == keaKey ) || ( key->keyType == fortezzaKey ) ||
 	     ( key->keyType == dhKey ) ) {
 	    requiredUsage |= KU_KEY_AGREEMENT;
@@ -1860,6 +1861,21 @@ CERT_IsCADERCert(SECItem *derCert, unsigned int *type) {
     return isCA;
 }
 
+PRBool
+CERT_IsRootDERCert(SECItem *derCert)
+{
+    CERTCertificate *cert;
+    PRBool isRoot;
+
+    /* This is okay -- only looks at extensions */
+    cert = CERT_DecodeDERCertificate(derCert, PR_FALSE, NULL);
+    if (cert == NULL) return PR_FALSE;
+
+    isRoot = cert->isRoot;
+    CERT_DestroyCertificate (cert);
+    return isRoot;
+}
+
 
 /*
  * is certa newer than certb?  If one is expired, pick the other one.
@@ -2606,10 +2622,9 @@ loser:
 
 PRBool CERT_IsUserCert(CERTCertificate* cert)
 {
-    if ( cert->trust &&
-        ((cert->trust->sslFlags & CERTDB_USER ) ||
+    if ( (cert->trust->sslFlags & CERTDB_USER ) ||
          (cert->trust->emailFlags & CERTDB_USER ) ||
-         (cert->trust->objectSigningFlags & CERTDB_USER )) ) {
+         (cert->trust->objectSigningFlags & CERTDB_USER ) ) {
         return PR_TRUE;
     } else {
         return PR_FALSE;
