@@ -32,7 +32,7 @@
  */
 
 #ifdef DEBUG
-static const char CVS_ID[] = "@(#) $RCSfile: ckhelper.c,v $ $Revision: 1.27 $ $Date: 2002/10/10 20:30:10 $ $Name: NSS_3_7_8_RTM $";
+static const char CVS_ID[] = "@(#) $RCSfile: ckhelper.c,v $ $Revision: 1.28 $ $Date: 2003/01/30 03:02:55 $ $Name: NSS_3_8_RTM $";
 #endif /* DEBUG */
 
 #ifndef NSSCKEPV_H
@@ -319,8 +319,7 @@ nssCryptokiCertificate_GetAttributes
   NSSDER *encodingOpt,
   NSSDER *issuerOpt,
   NSSDER *serialOpt,
-  NSSDER *subjectOpt,
-  NSSASCII7 **emailOpt
+  NSSDER *subjectOpt
 )
 {
     PRStatus status;
@@ -329,7 +328,7 @@ nssCryptokiCertificate_GetAttributes
     NSSSlot *slot;
     CK_ULONG template_size;
     CK_ATTRIBUTE_PTR attr;
-    CK_ATTRIBUTE cert_template[7];
+    CK_ATTRIBUTE cert_template[6];
     /* Set up a template of all options chosen by caller */
     NSS_CK_TEMPLATE_START(cert_template, attr, template_size);
     if (certTypeOpt) {
@@ -350,9 +349,6 @@ nssCryptokiCertificate_GetAttributes
     if (subjectOpt) {
 	NSS_CK_SET_ATTRIBUTE_NULL(attr, CKA_SUBJECT);
     }
-    if (emailOpt) {
-	NSS_CK_SET_ATTRIBUTE_NULL(attr, CKA_NETSCAPE_EMAIL);
-    }
     NSS_CK_TEMPLATE_FINISH(cert_template, attr, template_size);
     if (template_size == 0) {
 	/* caller didn't want anything */
@@ -397,9 +393,6 @@ nssCryptokiCertificate_GetAttributes
     if (subjectOpt) {
 	NSS_CK_ATTRIBUTE_TO_ITEM(&cert_template[i], subjectOpt); i++;
     }
-    if (emailOpt) {
-	NSS_CK_ATTRIBUTE_TO_UTF8(&cert_template[i], *emailOpt); i++;
-    }
     return PR_SUCCESS;
 }
 
