@@ -41,7 +41,7 @@
  */
 
 #ifdef DEBUG
-static const char DEV_CVS_ID[] = "@(#) $RCSfile: dev.h,v $ $Revision: 1.31.10.1 $ $Date: 2003/05/14 00:12:14 $ $Name: NSS_3_7_8_RTM $";
+static const char DEV_CVS_ID[] = "@(#) $RCSfile: dev.h,v $ $Revision: 1.32 $ $Date: 2003/01/30 03:02:55 $ $Name: NSS_3_8_RTM $";
 #endif /* DEBUG */
 
 #ifndef NSSCKT_H
@@ -323,18 +323,6 @@ nssSlot_Logout
   nssSession *sessionOpt
 );
 
-NSS_EXTERN void
-nssSlot_EnterMonitor
-(
-  NSSSlot *slot
-);
-
-NSS_EXTERN void
-nssSlot_ExitMonitor
-(
-  NSSSlot *slot
-);
-
 #define NSSSLOT_ASK_PASSWORD_FIRST_TIME -1
 #define NSSSLOT_ASK_PASSWORD_EVERY_TIME  0
 NSS_EXTERN void
@@ -744,8 +732,7 @@ nssCryptokiCertificate_GetAttributes
   NSSDER *encodingOpt,
   NSSDER *issuerOpt,
   NSSDER *serialOpt,
-  NSSDER *subjectOpt,
-  NSSASCII7 **emailOpt
+  NSSDER *subjectOpt
 );
 
 NSS_EXTERN PRStatus
