@@ -32,7 +32,7 @@
  */
 
 #ifdef DEBUG
-static const char CVS_ID[] = "@(#) $RCSfile: tdcache.c,v $ $Revision: 1.34.2.2 $ $Date: 2003/07/10 01:27:28 $ $Name: NSS_3_7_8_RTM $";
+static const char CVS_ID[] = "@(#) $RCSfile: tdcache.c,v $ $Revision: 1.35 $ $Date: 2003/01/08 21:48:45 $ $Name: NSS_3_8_RTM $";
 #endif /* DEBUG */
 
 #ifndef PKIM_H
@@ -488,15 +488,11 @@ nssTrustDomain_RemoveTokenCertsFromCache (
     for (i=0; i<dtor.numCerts; i++) {
 	if (dtor.certs[i]->object.numInstances == 0) {
 	    nssTrustDomain_RemoveCertFromCacheLOCKED(td, dtor.certs[i]);
-	    dtor.certs[i] = NULL;  /* skip this cert in the second for loop */
-	}
-    }
-    PZ_Unlock(td->cache->lock);
-    for (i=0; i<dtor.numCerts; i++) {
-	if (dtor.certs[i]) {
+	} else {
 	    STAN_ForceCERTCertificateUpdate(dtor.certs[i]);
 	}
     }
+    PZ_Unlock(td->cache->lock);
     nss_ZFreeIf(dtor.certs);
     return PR_SUCCESS;
 }
